@@ -3,25 +3,25 @@ package Catalyst::Plugin::RapidApp::RapidDbic::TableBase;
 use strict;
 use warnings;
 use Moose;
-extends 'RapidApp::DbicAppGrid3';
+extends 'RapidApp::Module::DbicGrid';
 with 
-  'RapidApp::AppGrid2::Role::ExcelExport',
+  'RapidApp::Module::Grid::Role::ExcelExport',
   # This is a bit of overlap/entaglement needed for 'NavCore' to be able to
   # work. However, NavCore is not always enabled, and this role only
   # enables itself if it is (i.e. Plugin::NavCore is present)
   'Catalyst::Plugin::RapidApp::NavCore::GridRole'
 ;
 
-#use RapidApp::DbicAppPropertyPage;
+#use RapidApp::Module::DbicPropPage;
 
-use RapidApp::Include qw(sugar perlutil);
+use RapidApp::Util qw(:all);
 
-has 'page_class', is => 'ro', isa => 'Str', default => 'RapidApp::DbicAppPropertyPage';
+has 'page_class', is => 'ro', isa => 'Str', default => 'RapidApp::Module::DbicPropPage';
 has 'page_params', is => 'ro', isa => 'HashRef', default => sub {{}};
 has 'no_page', is => 'ro', isa => 'Bool', default => 0;
 has 'source_model', is => 'ro', isa => 'Maybe[Str]', default => undef;
 
-# This is an option of RapidApp::AppGrid2 that will allow double-click to open Rows:
+# This is an option of RapidApp::Module::Grid that will allow double-click to open Rows:
 has '+open_record_class', lazy => 1, default => sub {
 	my $self = shift;
 	return undef if ($self->no_page);
