@@ -5,7 +5,7 @@ use warnings;
 # Min supported Perl is currently v5.10
 use 5.010;
 
-our $VERSION = '1.0010';
+our $VERSION = '1.0200';
 
 # ABSTRACT: Turnkey ajaxy webapps
 
@@ -29,6 +29,13 @@ our $ACTIVE_REQUEST_CONTEXT = undef;
 sub active_request_context { $ACTIVE_REQUEST_CONTEXT }
 
 
+# Convenience wrapper around RapidApp::Builder
+sub build_app {
+  shift if ($_[0] && $_[0] eq __PACKAGE__);
+  require RapidApp::Builder;
+  RapidApp::Builder->new( @_ )
+}
+
 
 # Private - will be removed in the future:
 our $ROOT_MODULE_INSTANCE = undef;
