@@ -1,7 +1,7 @@
 package RapidApp::Column;
 use strict;
 use warnings;
-use RapidApp::Include qw(sugar perlutil);
+use RapidApp::Util qw(:all);
 
 our @gridColParams= qw(
   name sortable hidden header dataIndex width editor menuDisabled tpl xtype
@@ -90,7 +90,9 @@ sub _set_menu_select_editor {
 
 			$val_to_disp{$sel->{value}} = '<div class="with-icon ' . $sel->{iconCls} . '">' . $sel->{text} . '</div>'
 				if($sel->{iconCls});
-				
+			
+      # This needs to be refactored into JS to be able to support mount_url prefix
+      # (GitHub Issue #114)
 			$val_to_disp{$sel->{value}} = '<img src="/assets/rapidapp/misc/static/s.gif" class="ra-icon-centered-16x16 ' . $sel->{iconCls} . '">'
 				if($sel->{iconCls} and jstrue($new->{render_icon_only}));
 		};
