@@ -941,7 +941,7 @@ sub controller_dispatch {
   if (defined $opt && !$self->accept_subargs) {
     # Handle the special case of browser requests for 'favicon.ico' (#57)
     return $c->redispatch_public_path(
-      '/assets/rapidapp/misc/static/images/rapidapp_icon_small.ico'
+      $c->default_favicon_url
     ) if ($opt eq 'favicon.ico' && !$c->is_ra_ajax_req);
 
     $self->c->log->debug(join('',"--> ",RED,BOLD,"unknown action: $opt",CLEAR)) if ($self->c->debug);
@@ -973,7 +973,7 @@ sub controller_dispatch {
       ## ---
       ## detect direct browser GET requests (i.e. not from the ExtJS client)
       ## and redirect them back to the #! hashnav path
-      $c->auto_hashnav_redirect_current;
+      $self->auto_hashnav_redirect_current;
       # ---
       $self->c->log->debug("--> " . GREEN . BOLD . "[content]" . CLEAR . ". (no action)")
         if($self->c->debug);
@@ -983,6 +983,14 @@ sub controller_dispatch {
   
 }
 
+# This call happens via local method so subclasses are able to override
+sub auto_hashnav_redirect_current {
+  my $self = shift;
+  $self->c->auto_hashnav_redirect_current
+}
+
+
+
 =head2 process_action( $actionName, [optional @args] )
 
 This routine handles the execution of a selected action.  The action must exist.
