@@ -59,32 +59,32 @@ sub BUILD {
   $self->apply_actions( nodes   => 'call_fetch_nodes' );
   $self->apply_actions( node   => 'call_fetch_node' ) if ($self->can('fetch_node'));
   
-  if($self->can('add_node')) {
+  if($self->op_available('add_node')) {
     $self->apply_actions( add   => 'call_add_node' );
     $self->apply_extconfig( add_node_url => $self->suburl('add') );
   }
   
-  if($self->can('delete_node')) {
+  if($self->op_available('delete_node')) {
     $self->apply_actions( delete   => 'call_delete_node' ); 
     $self->apply_extconfig( delete_node_url => $self->suburl('delete') );
   }
   
-  if($self->can('rename_node')) {
+  if($self->op_available('rename_node')) {
     $self->apply_actions( rename   => 'call_rename_node' );
     $self->apply_extconfig( rename_node_url => $self->suburl('rename') );
   }
   
-  if($self->can('copy_node')) {
+  if($self->op_available('copy_node')) {
     $self->apply_actions( copy => 'call_copy_node' );
     $self->apply_extconfig( copy_node_url => $self->suburl('copy') );
   }
   
-  if($self->can('move_node')) {
+  if($self->op_available('move_node')) {
     $self->apply_actions( move => 'call_move_node' );
     $self->apply_extconfig( move_node_url => $self->suburl('move') );
   }
   
-  if($self->can('expand_node')) {
+  if($self->op_available('expand_node')) {
     $self->apply_actions( expand   => 'call_expand_node' );
     $self->apply_extconfig( expand_node_url => $self->suburl('expand') );
   }
@@ -92,6 +92,13 @@ sub BUILD {
   $self->add_ONREQUEST_calls('init_onreq');
 }
 
+# New: this method is provided so subclass can hook/override
+sub op_available {
+  my ($self, $op_name) = @_;
+  $self->can($op_name)
+}
+
+
 around 'content' => sub {
   my $orig = shift;
   my $self = shift;
@@ -222,7 +229,7 @@ sub apply_path_specific_node_opts {
   # The id should be a fully qualified '/' delim path prefixed with the (parent) node 
   # path ($node supplied to this function). If it is not, assume it is a relative path 
   # and prefix it automatically:
-  $n->{id} = $node . '/' . $n->{id} unless ($n->{id} =~ /^${node}/);
+  $n->{id} = $node . '/' . $n->{id} unless ($n->{id} =~ /^\Q${node}\E/);
   
   # This is (imo) an ExtJS bug. It fixes the problem where empty nodes are automatically
   # made "leaf" nodes and get a stupid, non-folder default icon
@@ -244,7 +251,7 @@ has 'max_node_path_depth', is => 'ro', isa => 'Int', default => 100;
 
 # Max nested/recursive *single request* fetch depth that will be allowed. The tree can possibly
 # be deeper than this value, but it wouldn't be fetch-able in a single request
-has 'max_recursive_fetch_depth', is => 'ro', isa => 'Int', default => 10;
+has 'max_recursive_fetch_depth', is => 'ro', isa => 'Int', default => 3;
 
 our $DEEP_FETCH_DEPTH = 0;
 
@@ -283,49 +290,62 @@ sub call_fetch_nodes {
   my %seen_id = ();
   
   foreach my $n (@$nodes) {
-    if (jstrue($n->{leaf}) or (exists $n->{allowChildren} and ! jstrue($n->{allowChildren}))) {
-      $n->{loaded} = \1 unless (exists $n->{loaded});
-      next;
-    }
-    
-    $self->apply_path_specific_node_opts($node,$n) or next;
-    
-    ## If we've gotten this far, it means the current node can contain child nodes
-    
     die "Invalid node definition: duplicate id ($n->{id}): " . Dumper($n)
       if($seen_id{$n->{id}}++);
     
-    my $recurse = 0;
-    $recurse = 1 if (
-      ( $self->fetch_nodes_deep or jstrue($n->{expanded}) )
-      and ! exists $n->{children}
-      and ! jstrue($n->{loaded})
-      and $DEEP_FETCH_DEPTH < $self->max_recursive_fetch_depth
-    );
-    
-    if($recurse) { # Pre-fetch child nodes automatically:
-      my $children = $self->call_fetch_nodes($n->{id});
-      if(@$children > 0) {
-        $n->{children} = $children;
-        $n->{expanded} = \1 if ($self->default_expanded and ! exists $n->{expanded});
-      }
-      else {
-        # Set loaded to true if this node is empty (prevents being initialized with a +/- toggle):
-        $n->{loaded} = \1 unless (exists $n->{loaded});
-      }
-    }
-    
-    # WARNING: note that setting 'children' of a node to an empty array will prevent subsequent
-    # ajax loading of the node's children (should any exist later)
+    $self->prepare_node($n,$node);
   }
   
   return $nodes;
 }
 
+sub prepare_node {
+  my ($self, $n, $parent) = @_;
+  
+  if (jstrue($n->{leaf}) or (exists $n->{allowChildren} and ! jstrue($n->{allowChildren}))) {
+    $n->{loaded} = \1 unless (exists $n->{loaded});
+    return $n;
+  }
+  
+  if($parent) {
+    $self->apply_path_specific_node_opts($parent,$n) or return $n;
+  }
+  
+  ## If we've gotten this far, it means the current node can contain child nodes
+  
+  my $recurse = 0;
+  $recurse = 1 if (
+    ( $self->fetch_nodes_deep or jstrue($n->{expanded}) )
+    and ! exists $n->{children}
+    and ! jstrue($n->{loaded})
+    and $DEEP_FETCH_DEPTH < $self->max_recursive_fetch_depth
+  );
+  
+  if($recurse) { # Pre-fetch child nodes automatically:
+    my $children = $self->call_fetch_nodes($n->{id});
+    if(@$children > 0) {
+      $n->{children} = $children;
+      $n->{expanded} = \1 if ($self->default_expanded and ! exists $n->{expanded});
+    }
+    else {
+      # Set loaded to true if this node is empty (prevents being initialized with a +/- toggle):
+      $n->{loaded} = \1 unless (exists $n->{loaded});
+    }
+  }
+  
+  # WARNING: note that setting 'children' of a node to an empty array will prevent subsequent
+  # ajax loading of the node's children (should any exist later)
+  
+  $n
+}
+
+
 sub call_fetch_node {
   my $self = shift;
   my $node = $self->c->req->params->{node};
-  return $self->fetch_node($node);
+  my $n = $self->fetch_node($node);
+  $self->prepare_node($n);
+  $n
 }
 
 sub call_add_node {
